On 3/27/2024 6:25 AM, Mateusz Polchlopek wrote:

...

diff --git a/drivers/net/ethernet/intel/iavf/iavf_txrx.c 
b/drivers/net/ethernet/intel/iavf/iavf_txrx.c
index b71484c87a84..c9c4f255bc8b 100644
--- a/drivers/net/ethernet/intel/iavf/iavf_txrx.c
+++ b/drivers/net/ethernet/intel/iavf/iavf_txrx.c

...

  /**
  * iavf_rx_checksum - Indicate in skb if hw indicated a good cksum
   * @vsi: the VSI we care about
   * @skb: skb currently being received and modified
- * @rx_desc: the receive descriptor
+ * @ptype: decoded ptype information
+ * @csum_bits: decoded Rx descriptor information
   **/
-static void iavf_rx_checksum(struct iavf_vsi *vsi,
-                            struct sk_buff *skb,
-                            union iavf_rx_desc *rx_desc)
+static inline void iavf_rx_csum(struct iavf_vsi *vsi, struct sk_buff *skb,

Please don't use 'inline' in c files. More usages throughout this patch as well.

+                               struct iavf_rx_ptype_decoded *ptype,
+                               struct iavf_rx_csum_decoded *csum_bits)
  {
@@

  /**
- * iavf_rx_checksum - Indicate in skb if hw indicated a good cksum
+ * iavf_rx_csum - Indicate in skb if hw indicated a good checksum
   * @vsi: the VSI we care about
   * @skb: skb currently being received and modified

Reply via email to